@@ -86,7 +86,7 @@
 #define KGLOBALACCELPRIVATE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KGLOBALACCELPRIVATE_NO_DEPRECATED
-#  define KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55500
+#  define KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55b00
 #endif
 #ifdef KGLOBALACCELPRIVATE_NO_DEPRECATED_WARNINGS
 #  define KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE 0x55500
+#    define KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE 0x55b00
 #  endif
 #endif
 
@@ -115,7 +115,14 @@
 #else
 #  define KGLOBALACCELPRIVATE_DEPRECATED_VERSION_4_3(text)
 #endif
+
+#if KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE >= 0x55a00
+#  define KGLOBALACCELPRIVATE_DEPRECATED_VERSION_5_90(text) KGLOBALACCELPRIVATE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KGLOBALACCELPRIVATE_DEPRECATED_VERSION_5_90(text)
+#endif
 #define KGLOBALACCELPRIVATE_DEPRECATED_VERSION_4(minor, text)      KGLOBALACCELPRIVATE_DEPRECATED_VERSION_4_##minor(text)
+#define KGLOBALACCELPRIVATE_DEPRECATED_VERSION_5(minor, text)      KGLOBALACCELPRIVATE_DEPRECATED_VERSION_5_##minor(text)
 #define KGLOBALACCELPRIVATE_DEPRECATED_VERSION(major, minor, text) KGLOBALACCELPRIVATE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KGLOBALACCELPRIVATE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KGLOBALACCELPRIVATE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
 #if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
@@ -180,7 +187,7 @@
 #define KGLOBALACCELPRIVATE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KGLOBALACCELPRIVATE_NO_DEPRECATED
-#  define KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55500
+#  define KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55b00
 #endif
 #ifdef KGLOBALACCELPRIVATE_NO_DEPRECATED_WARNINGS
 #  define KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE 0
@@ -190,7 +197,7 @@
 #  ifdef KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE KGLOBALACCELPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE 0x55500
+#    define KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE 0x55b00
 #  endif
 #endif
 
@@ -209,7 +216,14 @@
 #else
 #  define KGLOBALACCELPRIVATE_DEPRECATED_VERSION_4_3(text)
 #endif
+
+#if KGLOBALACCELPRIVATE_DEPRECATED_WARNINGS_SINCE >= 0x55a00
+#  define KGLOBALACCELPRIVATE_DEPRECATED_VERSION_5_90(text) KGLOBALACCELPRIVATE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KGLOBALACCELPRIVATE_DEPRECATED_VERSION_5_90(text)
+#endif
 #define KGLOBALACCELPRIVATE_DEPRECATED_VERSION_4(minor, text)      KGLOBALACCELPRIVATE_DEPRECATED_VERSION_4_##minor(text)
+#define KGLOBALACCELPRIVATE_DEPRECATED_VERSION_5(minor, text)      KGLOBALACCELPRIVATE_DEPRECATED_VERSION_5_##minor(text)
 #define KGLOBALACCELPRIVATE_DEPRECATED_VERSION(major, minor, text) KGLOBALACCELPRIVATE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KGLOBALACCELPRIVATE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KGLOBALACCELPRIVATE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
 #if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
